package net.cs76.sections.lamegame;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

public class LameGame extends Activity {
	public static SimpleDateFormat myDateFormat = new SimpleDateFormat("MMM d");
	
	private HighScoreDataHelper highScoreAccessor;

    private Button submitButton;
	private Button showScoresButton;

	private EditText playerName;
	private EditText gameId;
	private EditText score;


	/** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        // we'll use this to manipulate the list of high scores
		highScoreAccessor = new HighScoreDataHelper(getApplicationContext());

		submitButton = (Button) findViewById(R.id.submitButton);
		submitButton.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				submitScore();
			}
		});

		showScoresButton = (Button) findViewById(R.id.showScoresButton);
		showScoresButton.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				Intent highScoreListActivity = new Intent(getBaseContext(), HighScoreList.class);
				highScoreListActivity.putExtra(HighScoreList.EXTRA_GAME_ID, gameId.getText().toString());
				startActivity(highScoreListActivity);
			}
		});

		gameId = (EditText) findViewById(R.id.gameId);
		playerName = (EditText) findViewById(R.id.playerName);
		score = (EditText) findViewById(R.id.score);
    }

    // throw the score at the database
	private void submitScore() {
		HighScoreEntry entry = null;
		try {
			entry = new HighScoreEntry(playerName.getText().toString(), new Date(), Double.valueOf(score.getText()
					.toString()), Long.valueOf(gameId.getText().toString()));
		} catch (NumberFormatException e) {
			Toast.makeText(getApplicationContext(), R.string.badInput, Toast.LENGTH_LONG).show();
			return;
		}
		
		
		double highest = Double.NEGATIVE_INFINITY;
		List<HighScoreEntry> scores = highScoreAccessor.getByGameId(entry.getGameId());
		if (scores.size() > 0) {
			for (HighScoreEntry hse : scores) { // simply look for the highest existing score
				if (highest < hse.getScore()) {
					highest = hse.getScore();
				}
			}
		}
		
		// give a little "congratulations" message if yours is the highest score so far
		if (highest < entry.getScore()) { // you beat everyone else (including yourself) on this game!
			Toast newHighScore = Toast.makeText(getApplicationContext(), R.string.newHighScore, Toast.LENGTH_LONG);
			newHighScore.show();
		} else {
			Toast.makeText(getApplicationContext(), R.string.saving, Toast.LENGTH_LONG).show();
		}
		
		// well, we could probably push this into the HighScoreDataHelper
		if (highScoreAccessor.alreadyExists(entry)) { // only store a single score per player/gameID combination
			highScoreAccessor.update(entry);
		} else {
			highScoreAccessor.insert(entry);
		}
	}
}